[llvm-commits] CVS: llvm/include/llvm/ADT/IndexedMap.h

Chris Lattner sabre at nondot.org
Wed Jan 31 21:28:26 PST 2007



Changes in directory llvm/include/llvm/ADT:

IndexedMap.h updated: 1.9 -> 1.10
---
Log message:

rename DenseMap -> IndexedMap.


---
Diffs of the changes:  (+7 -7)

 IndexedMap.h |   14 +++++++-------
 1 files changed, 7 insertions(+), 7 deletions(-)


Index: llvm/include/llvm/ADT/IndexedMap.h
diff -u llvm/include/llvm/ADT/IndexedMap.h:1.9 llvm/include/llvm/ADT/IndexedMap.h:1.10
--- llvm/include/llvm/ADT/IndexedMap.h:1.9	Thu Sep 30 16:39:47 2004
+++ llvm/include/llvm/ADT/IndexedMap.h	Wed Jan 31 23:28:10 2007
@@ -1,4 +1,4 @@
-//===- llvm/ADT/DenseMap.h - A dense map implmentation ----------*- C++ -*-===//
+//===- llvm/ADT/IndexedMap.h - An index map implementation ------*- C++ -*-===//
 //
 //                     The LLVM Compiler Infrastructure
 //
@@ -7,7 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 //
 // This file implements a dense map. A dense map template takes two
 // types. The first is the mapped type and the second is a functor
 // that maps its argument to a size_t. On instantiation a "null" value
 // can be provided to be used as a "does not exist" indicator in the
@@ -17,8 +17,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_ADT_DENSEMAP_H
-#define LLVM_ADT_DENSEMAP_H
+#ifndef LLVM_ADT_INDEXEDMAP_H
+#define LLVM_ADT_INDEXEDMAP_H
 
 #include <functional>
 #include <vector>
@@ -33,7 +33,7 @@
   };
 
   template <typename T, typename ToIndexT = IdentityFunctor>
-  class DenseMap {
+  class IndexMap {
     typedef typename ToIndexT::argument_type IndexT;
     typedef std::vector<T> StorageT;
     StorageT storage_;
@@ -41,9 +41,9 @@
     ToIndexT toIndex_;
 
   public:
-    DenseMap() : nullVal_(T()) { }
+    IndexMap() : nullVal_(T()) { }
 
-    explicit DenseMap(const T& val) : nullVal_(val) { }
+    explicit IndexMap(const T& val) : nullVal_(val) { }
 
     typename StorageT::reference operator[](IndexT n) {
       assert(toIndex_(n) < storage_.size() && "index out of bounds!");
@@ -7,7 +7,7 @@
 //===----------------------------------------------------------------------===//
 //
-// This file implements a dense map. A dense map template takes two
+// This file implements an indexed map. The index map template takes two
 // types. The first is the mapped type and the second is a functor
 // that maps its argument to a size_t. On instantiation a "null" value






More information about the llvm-commits mailing list